      SUBROUTINE CGLALO (OLDLAT, OLDLON, CGLAT, CGLON)
C-----------------------------------------------------------------------
C
C     THIS SUBROUTINE IS THE HAKURA/GUSTAFSSON COORDINATE TRANSFORMATION
C     OF GEOGRAPHIC LATITUDE AND LONGITUDE TO COORECTED GEOMAGNETIC
C     LATITUDE AND LONGITUDE.
C
C     RE: A REVISED CORRECTED GEOMAGNETIC COORDINATE SYSTEM,
C         KGO REPORT NO. 694 (APRIL 1969), KIRUNA GEOPHYSICAL 
C         OBSERVATORY, S-981 01 KIRUNA 1, SWEDEN. (BASED ON IGRF65
C         MODEL)
C
C     THIS ROUTINE HAS BEEN CORRECTED AND UPDATED BY MAURIZIO CANDIDI
C     AND HERBERT KROEHL OF USDOC/NOAA/DSD, BOULDER, CO 80303.
C     THIS ROUTINE HAS BEEN CORRECTED TO ALLOW CALCULATION OF CGM
C     COORDINATES RIGHT UP TO THE GEOGRAPHIC POLES. RKR 80/02/20.
C                            R. K. ROSICH, USDOC/NTIA/ITS, 79/02/23.
C
C     MODIFIED TO USE ARGUMENTS BASED ON IGRF80 PRESENTED BY GUSTAFSSON
C     AT CHAPMAN CONF.,IRVINGTON,VA, APRIL 83.  DISCONTINUITIES IN HIS
C     TABLE HAVE BEEN REMOVED BY CURVE FITTING.
C           F. J. RICH, A.F. GEOPHYS LAB., BEDFORD, MA 01731 AUG 83 
C
C     GEOMAGNETIC LATITUDE AND LONGITUDE COORDINATES PREVIOUSLY
C     OMITTED IN THE EQUATORIAL REGION BETWEEN +22 DEGREES AND
C     -10 DEGREES GEOGRAPHIC LATITUDE (INCLUSIVE) WERE OBTAINED
C     BY APPLYING A SMOOTH CUBIC REGRESSION ACROSS THE NULL REGION.
C     THIS INTERPOLATION WAS PERFORMED BY RADEX,INC., OCTOBER,1983.
C
C-----------------------------------------------------------------------
C     MODIFIED TO USE ARGUMENTS BASED ON IGRF 2010 MODEL. THE
C     COORDINATES IN THE AREA OF THE SOUTH ATLANTIC ANOMALY AND THE
C     DIP EQUATOR HAVE BEEN FURTHER CORRECTED BY A RESAMPLING OF POINTS
C     BASED ON SMOOTHED DERIVATIVES BETWEEN CG POINTS.
C
C     THIS VERSION DOES NOT CONTAIN THE POLAR TRIANGULATION SCHEME AS
C     SEEN IN EARLIER VERSIONS. AN UPDATED EARLIER VERSION DOES EXIST.
C
C                                  W. HERES, AER INC., AUGUST 2006
C-----------------------------------------------------------------------
C
C     ARGUMENTS:
C        INPUT:
C           OLDLAT = GEOGRAPHIC LATITUDE (DEGREES, +=N, -=S),
C           OLDLON = GEOGRAPHIC LONGITUDE (DEGREES E. LONG.),
C        OUTPUT:
C           CGLAT = CORRECTED GEOMAGNETIC LATITUDE (DEGREES, +=N, -=S),
C           CGLON = CORRECTED GEOMAGNETIC LONGITUDE (DEGREES E. LONG.).
C
C           THE TABLE OF CORRECTED GEOMAGNETIC LATITUDE (2 DEG STEP)
C           AND LONGITUDE (10 DEG STEP) PAIRS IS FOUND IN ARRAY A.
C
C-----------------------------------------------------------------------
C     Updated with points generated from the IGRF2010 model. Based on
C     previous work of C. A. Hein of Radex, Inc and Will Heres of AER.
C
C     UPDATED BY:
C
C     Plamen Krastev & Steve O'Malley
C     AER, Inc.
C     131 Hartwell Avenue
C     Lexington, MA 02421
C     somalley@aer.com
C
C-----------------------------------------------------------------------

      IMPLICIT REAL*8(A-H,O-Z)
      DIMENSION A(2,36,89)

      DATA CGMNLA,CGMNLO/  83.52, 170.16/ CGMSLA,CGMSLO/ -74.14,  19.53/
C 
C
      DATA((A(I,J,  1),I=1,2),J=1,36)/
     $  83.46,151.58, 83.18,152.28, 82.92,153.44, 82.67,154.97,
     $  82.46,156.78, 82.27,158.86, 82.11,161.10, 81.98,163.52,
     $  81.89,166.03, 81.83,168.60, 81.81,171.16, 81.83,173.71,
     $  81.88,176.21, 81.96,178.59, 82.09,180.83, 82.25,182.86,
     $  82.44,184.68, 82.67,186.21, 82.92,187.39, 83.20,188.18,
     $  83.50,188.51, 83.81,188.28, 84.12,187.44, 84.42,185.89,
     $  84.69,183.63, 84.92,180.64, 85.09,177.00, 85.19,172.86,
     $  85.22,168.47, 85.16,164.20, 85.04,160.33, 84.85,157.09,
     $  84.62,154.53, 84.34,152.76, 84.05,151.73, 83.76,151.35/
C
      DATA((A(I,J,  2),I=1,2),J=1,36)/
     $  82.78,134.93, 82.28,137.35, 81.83,140.24, 81.43,143.50,
     $  81.09,147.05, 80.80,150.86, 80.56,154.86, 80.37,158.99,
     $  80.23,163.24, 80.14,167.52, 80.10,171.81, 80.11,176.06,
     $  80.17,180.22, 80.29,184.26, 80.46,188.12, 80.70,191.78,
     $  81.01,195.19, 81.37,198.29, 81.81,201.06, 82.31,203.38,
     $  82.86,205.19, 83.47,206.31, 84.11,206.56, 84.77,205.57,
     $  85.43,202.90, 86.03,197.86, 86.53,189.69, 86.84,178.28,
     $  86.91,164.90, 86.71,152.43, 86.30,142.99, 85.76,136.83,
     $  85.15,133.49, 84.53,132.06, 83.92,132.07, 83.33,133.10/
C
      DATA((A(I,J,  3),I=1,2),J=1,36)/
     $  81.62,122.01, 80.99,126.09, 80.43,130.46, 79.95,135.10,
     $  79.54,140.01, 79.21,145.10, 78.93,150.36, 78.71,155.76,
     $  78.55,161.24, 78.43,166.75, 78.37,172.27, 78.37,177.73,
     $  78.42,183.07, 78.53,188.28, 78.72,193.32, 78.99,198.13,
     $  79.35,202.73, 79.80,207.07, 80.35,211.14, 80.99,214.91,
     $  81.74,218.34, 82.58,221.37, 83.49,223.85, 84.48,225.57,
     $  85.52,225.99, 86.58,223.97, 87.60,216.51, 88.41,194.87,
     $  88.56,152.82, 87.90,124.25, 86.95,113.92, 85.94,110.84,
     $  84.96,110.95, 84.02,112.58, 83.14,115.12, 82.34,118.35/
C
      DATA((A(I,J,  4),I=1,2),J=1,36)/
     $  80.16,112.54, 79.44,117.81, 78.83,123.27, 78.31,128.93,
     $  77.88,134.76, 77.52,140.80, 77.24,147.00, 77.01,153.32,
     $  76.84,159.73, 76.71,166.17, 76.63,172.61, 76.60,178.97,
     $  76.63,185.22, 76.73,191.29, 76.90,197.16, 77.17,202.82,
     $  77.51,208.25, 78.02,213.47, 78.66,218.50, 79.41,223.35,
     $  80.29,228.06, 81.29,232.69, 82.40,237.29, 83.62,241.93,
     $  84.92,246.78, 86.28,252.16, 87.69,259.25, 89.08,275.99,
     $  89.33, 49.55, 87.98, 73.77, 86.62, 81.69, 85.32, 87.41,
     $  84.09, 92.55, 82.95, 97.47, 81.91,102.42, 80.98,107.42/
C
      DATA((A(I,J,  5),I=1,2),J=1,36)/
     $  78.49,105.57, 77.73,111.68, 77.09,117.89, 76.56,124.25,
     $  76.13,130.77, 75.78,137.48, 75.50,144.37, 75.28,151.40,
     $  75.11,158.54, 74.97,165.72, 74.88,172.88, 74.82,179.96,
     $  74.81,186.90, 74.87,193.63, 75.02,200.14, 75.27,206.41,
     $  75.60,212.44, 76.14,218.28, 76.82,223.97, 77.64,229.57,
     $  78.62,235.19, 79.75,240.95, 81.00,247.05, 82.37,253.79,
     $  83.82,261.81, 85.29,272.44, 86.70,289.10, 87.76,320.78,
     $  87.81,  9.40, 86.84, 42.77, 85.51, 60.28, 84.13, 71.35,
     $  82.79, 79.70, 81.54, 86.80, 80.40, 93.28, 79.38, 99.48/
C
      DATA((A(I,J,  6),I=1,2),J=1,36)/
     $  76.70,100.34, 75.91,107.00, 75.26,113.72, 74.74,120.58,
     $  74.32,127.60, 73.99,134.84, 73.73,142.25, 73.53,149.85,
     $  73.36,157.57, 73.22,165.35, 73.10,173.12, 73.01,180.80,
     $  72.96,188.30, 72.97,195.57, 73.07,202.56, 73.29,209.27,
     $  73.63,215.75, 74.19,222.01, 74.87,228.15, 75.75,234.27,
     $  76.80,240.51, 78.04,247.03, 79.41,254.11, 80.88,262.16,
     $  82.41,271.92, 83.92,284.79, 85.25,303.29, 86.10,330.48,
     $  86.10,  3.00, 85.29, 29.92, 84.03, 48.26, 82.63, 61.13,
     $  81.23, 71.02, 79.91, 79.30, 78.70, 86.69, 77.63, 93.63/
C
      DATA((A(I,J,  7),I=1,2),J=1,36)/
     $  74.81, 96.29, 74.01,103.33, 73.36,110.40, 72.85,117.60,
     $  72.44,124.96, 72.15,132.63, 71.93,140.51, 71.74,148.59,
     $  71.59,156.81, 71.44,165.11, 71.30,173.38, 71.17,181.53,
     $  71.08,189.49, 71.03,197.18, 71.08,204.56, 71.24,211.64,
     $  71.62,218.44, 72.18,225.03, 72.82,231.46, 73.76,237.93,
     $  74.89,244.58, 76.21,251.62, 77.68,259.34, 79.24,268.17,
     $  80.84,278.85, 82.37,292.49, 83.63,310.71, 84.38,334.35,
     $  84.35,  0.56, 83.59, 23.58, 82.37, 41.17, 80.96, 54.44,
     $  79.52, 64.98, 78.15, 73.87, 76.88, 81.79, 75.77, 89.18/
C
      DATA((A(I,J,  8),I=1,2),J=1,36)/
     $  72.83, 93.08, 72.01,100.36, 71.39,107.73, 70.91,115.26,
     $  70.56,122.99, 70.29,130.96, 70.09,139.18, 69.93,147.61,
     $  69.78,156.21, 69.64,164.89, 69.48,173.55, 69.32,182.09,
     $  69.18,190.40, 69.08,198.42, 69.07,206.10, 69.19,213.45,
     $  69.57,220.50, 70.13,227.34, 70.70,234.06, 71.65,240.80,
     $  72.88,247.76, 74.30,255.16, 75.86,263.30, 77.50,272.62,
     $  79.16,283.75, 80.70,297.60, 81.94,315.13, 82.62,336.46,
     $  82.58,359.27, 81.84, 19.89, 80.63, 36.61, 79.20, 49.84,
     $  77.71, 60.62, 76.28, 69.82, 74.97, 78.05, 73.81, 85.71/
C
      DATA((A(I,J,  9),I=1,2),J=1,36)/
     $  70.80, 90.55, 70.02, 98.06, 69.42,105.64, 68.96,113.38,
     $  68.64,121.35, 68.40,129.58, 68.23,138.07, 68.09,146.80,
     $  67.96,155.70, 67.81,164.70, 67.63,173.69, 67.44,182.54,
     $  67.25,191.15, 67.11,199.44, 67.05,207.37, 67.12,214.93,
     $  67.50,222.19, 68.05,229.21, 68.59,236.13, 69.58,243.08,
     $  70.81,250.25, 72.26,257.87, 73.96,266.38, 75.69,276.00,
     $  77.41,287.37, 78.97,301.18, 80.19,318.06, 80.85,337.79,
     $  80.79,358.47, 80.04, 17.51, 78.83, 33.48, 77.36, 46.52,
     $  75.82, 57.37, 74.34, 66.73, 72.97, 75.14, 71.77, 82.99/
C
      DATA((A(I,J, 10),I=1,2),J=1,36)/
     $  68.75, 88.48, 67.98, 96.13, 67.40,103.87, 66.98,111.80,
     $  66.69,119.97, 66.49,128.42, 66.35,137.14, 66.23,146.12,
     $  66.11,155.28, 65.95,164.54, 65.77,173.79, 65.54,182.90,
     $  65.31,191.76, 65.12,200.27, 65.01,208.40, 65.04,216.15,
     $  65.41,223.56, 65.75,230.75, 66.47,237.84, 67.47,244.95,
     $  68.75,252.30, 70.26,260.11, 71.96,268.68, 73.81,278.62,
     $  75.59,290.12, 77.19,303.82, 78.41,320.14, 79.05,338.70,
     $  78.97,357.96, 78.22, 15.86, 76.97, 31.23, 75.46, 44.07,
     $  73.87, 54.92, 72.30, 64.42, 70.91, 72.86, 69.73, 80.79/
C
      DATA((A(I,J, 11),I=1,2),J=1,36)/
     $  66.66, 86.73, 65.89, 94.46, 65.35,102.35, 64.97,110.44,
     $  64.71,118.80, 64.55,127.44, 64.44,136.36, 64.34,145.54,
     $  64.22,154.91, 64.07,164.40, 63.86,173.87, 63.61,183.21,
     $  63.34,192.27, 63.10,200.98, 62.94,209.28, 62.93,217.18,
     $  63.13,224.73, 63.59,232.05, 64.33,239.26, 65.37,246.52,
     $  66.67,254.01, 68.23,261.97, 69.99,270.69, 71.86,280.54,
     $  73.73,292.24, 75.37,305.83, 76.60,321.67, 77.23,339.38,
     $  77.14,357.61, 76.37, 14.67, 75.09, 29.58, 73.52, 42.24,
     $  71.85, 53.11, 70.26, 62.45, 68.84, 70.94, 67.63, 78.94/
C
      DATA((A(I,J, 12),I=1,2),J=1,36)/
     $  64.51, 85.21, 63.78, 93.08, 63.27,101.09, 62.93,109.32,
     $  62.72,117.82, 62.58,126.62, 62.49,135.71, 62.41,145.06,
     $  62.31,154.61, 62.15,164.27, 61.93,173.93, 61.66,183.45,
     $  61.35,192.71, 61.05,201.58, 60.84,210.03, 60.79,218.05,
     $  60.96,225.72, 61.41,233.15, 62.17,240.47, 63.23,247.85,
     $  64.59,255.47, 66.19,263.55, 68.00,272.37, 69.92,282.29,
     $  71.82,293.75, 73.52,307.35, 74.77,322.84, 75.40,339.90,
     $  75.30,357.37, 74.50, 13.82, 73.17, 28.39, 71.54, 40.92,
     $  69.82, 51.51, 68.18, 60.83, 66.71, 69.34, 65.47, 77.36/
C
      DATA((A(I,J, 13),I=1,2),J=1,36)/
     $  62.33, 83.93, 61.64, 91.88, 61.17, 99.99, 60.87,108.35,
     $  60.69,116.99, 60.59,125.93, 60.53,135.16, 60.46,144.65,
     $  60.36,154.35, 60.21,164.16, 59.98,173.97, 59.68,183.65,
     $  59.33,193.06, 59.00,202.09, 58.74,210.66, 58.64,218.80,
     $  58.79,226.57, 59.23,234.08, 59.99,241.50, 61.08,248.99,
     $  62.47,256.72, 64.13,264.92, 65.99,273.82, 67.95,283.77,
     $  69.90,295.19, 71.64,308.42, 72.92,323.71, 73.56,340.30,
     $  73.44,357.22, 72.62, 13.27, 71.24, 27.50, 69.53, 39.68,
     $  67.74, 50.19, 66.02, 59.48, 64.52, 67.96, 63.29, 76.02/
C
      DATA((A(I,J, 14),I=1,2),J=1,36)/
     $  60.12, 82.81, 59.46, 90.83, 59.04, 99.04, 58.79,107.51,
     $  58.65,116.28, 58.58,125.35, 58.54,134.71, 58.48,144.31,
     $  58.39,154.12, 58.24,164.05, 58.00,173.99, 57.68,183.81,
     $  57.30,193.36, 56.92,202.51, 56.61,211.20, 56.48,219.43,
     $  56.60,227.28, 57.03,234.88, 57.80,242.39, 58.92,249.98,
     $  60.35,257.81, 62.05,266.10, 63.96,275.08, 65.97,285.06,
     $  67.96,296.41, 69.74,309.48, 71.07,324.34, 71.73,340.56,
     $  71.61,357.10, 70.72, 12.73, 69.27, 26.63, 67.49, 38.67,
     $  65.60, 49.10, 63.83, 58.32, 62.30, 66.79, 61.06, 74.86/
C
      DATA((A(I,J, 15),I=1,2),J=1,36)/
     $  57.86, 81.80, 57.25, 89.89, 56.87, 98.19, 56.67,106.78,
     $  56.58,115.67, 56.54,124.87, 56.52,134.33, 56.48,144.04,
     $  56.39,153.93, 56.23,163.96, 55.99,174.00, 55.66,183.93,
     $  55.25,193.59, 54.83,202.85, 54.48,211.63, 54.32,219.95,
     $  54.42,227.88, 54.84,235.57, 55.63,243.16, 56.76,250.84,
     $  58.22,258.77, 59.96,267.15, 61.91,276.19, 63.97,286.19,
     $  66.00,297.48, 67.81,310.37, 69.16,324.95, 69.84,340.79,
     $  69.71,356.94, 68.79, 12.24, 67.27, 25.93, 65.39, 37.85,
     $  63.44, 48.16, 61.61, 57.32, 60.03, 65.76, 58.78, 73.83/
C
      DATA((A(I,J, 16),I=1,2),J=1,36)/
     $  55.55, 80.91, 54.99, 89.05, 54.68, 97.44, 54.54,106.14,
     $  54.50,115.15, 54.49,124.45, 54.49,134.02, 54.45,143.81,
     $  54.36,153.78, 54.21,163.88, 53.96,174.00, 53.61,184.01,
     $  53.18,193.77, 52.73,203.12, 52.35,211.99, 52.15,220.38,
     $  52.23,228.39, 52.66,236.15, 53.46,243.83, 54.62,251.60,
     $  56.10,259.63, 57.87,268.08, 59.84,277.19, 61.94,287.19,
     $  64.00,298.42, 65.85,311.15, 67.24,325.47, 67.93,340.99,
     $  67.79,356.80, 66.83, 11.84, 65.23, 25.37, 63.28, 37.11,
     $  61.24, 47.34, 59.33, 56.44, 57.70, 64.84, 56.44, 72.90/
C
      DATA((A(I,J, 17),I=1,2),J=1,36)/
     $  53.20, 80.10, 52.69, 88.30, 52.45, 96.77, 52.38,105.57,
     $  52.39,114.69, 52.42,124.10, 52.43,133.77, 52.40,143.63,
     $  52.31,153.66, 52.16,163.80, 51.90,173.98, 51.54,184.06,
     $  51.09,193.90, 50.61,203.33, 50.20,212.28, 49.98,220.74,
     $  50.06,228.81, 50.49,236.64, 51.31,244.41, 52.49,252.28,
     $  53.99,260.40, 55.78,268.94, 57.77,278.09, 59.89,288.10,
     $  61.99,299.26, 63.87,311.84, 65.29,325.92, 66.01,341.15,
     $  65.86,356.70, 64.85, 11.51, 63.19, 24.85, 61.14, 36.49,
     $  59.00, 46.63, 57.00, 55.67, 55.33, 64.03, 54.06, 72.08/
C
      DATA((A(I,J, 18),I=1,2),J=1,36)/
     $  50.78, 79.38, 50.34, 87.62, 50.18, 96.17, 50.19,105.06,
     $  50.26,114.29, 50.34,123.81, 50.36,133.56, 50.33,143.49,
     $  50.24,153.56, 50.08,163.74, 49.83,173.95, 49.46,184.09,
     $  49.00,193.99, 48.50,203.49, 48.06,212.50, 47.82,221.03,
     $  47.89,229.17, 48.34,237.08, 49.18,244.93, 50.38,252.89,
     $  51.90,261.11, 53.70,269.73, 55.71,278.92, 57.84,288.93,
     $  59.96,300.01, 61.88,312.45, 63.33,326.31, 64.06,341.29,
     $  63.90,356.58, 62.86, 11.20, 61.12, 24.40, 58.97, 35.94,
     $  56.71, 46.02, 54.62, 55.00, 52.89, 63.31, 51.61, 71.34/
C
      DATA((A(I,J, 19),I=1,2),J=1,36)/
     $  48.31, 78.72, 47.95, 87.00, 47.88, 95.63, 47.98,104.62,
     $  48.12,113.95, 48.24,123.58, 48.28,133.41, 48.25,143.39,
     $  48.15,153.49, 47.98,163.68, 47.73,173.91, 47.37,184.08,
     $  46.90,194.04, 46.38,203.60, 45.91,212.68, 45.66,221.26,
     $  45.73,229.46, 46.20,237.45, 47.06,245.39, 48.29,253.45,
     $  49.83,261.77, 51.63,270.46, 53.64,279.70, 55.78,289.69,
     $  57.92,300.71, 59.86,312.99, 61.35,326.65, 62.10,341.39,
     $  61.94,356.47, 60.86, 10.92, 59.04, 24.01, 56.77, 35.48,
     $  54.39, 45.48, 52.19, 54.40, 50.39, 62.67, 49.10, 70.68/
C
      DATA((A(I,J, 20),I=1,2),J=1,36)/
     $  45.79, 78.12, 45.51, 86.45, 45.55, 95.14, 45.75,104.22,
     $  45.97,113.66, 46.13,123.38, 46.18,133.29, 46.14,143.32,
     $  46.04,153.43, 45.87,163.62, 45.62,173.86, 45.27,184.06,
     $  44.79,194.05, 44.25,203.67, 43.77,212.80, 43.51,221.44,
     $  43.59,229.70, 44.08,237.76, 44.97,245.80, 46.22,253.97,
     $  47.78,262.38, 49.58,271.15, 51.59,280.43, 53.72,290.41,
     $  55.87,301.35, 57.83,313.50, 59.35,326.95, 60.13,341.48,
     $  59.97,356.36, 58.85, 10.67, 56.94, 23.67, 54.55, 35.07,
     $  52.02, 45.01, 49.70, 53.87, 47.83, 62.09, 46.52, 70.07/
C
      DATA((A(I,J, 21),I=1,2),J=1,36)/
     $  43.20, 77.59, 43.02, 85.95, 43.18, 94.70, 43.49,103.86,
     $  43.80,113.40, 44.01,123.22, 44.08,133.21, 44.03,143.28,
     $  43.91,153.39, 43.74,163.57, 43.50,173.80, 43.15,184.01,
     $  42.68,194.04, 42.13,203.71, 41.63,212.89, 41.36,221.58,
     $  41.45,229.90, 41.97,238.04, 42.90,246.17, 44.18,254.45,
     $  45.74,262.96, 47.54,271.81, 49.54,281.13, 51.67,291.09,
     $  53.81,301.95, 55.79,313.96, 57.33,327.22, 58.14,341.53,
     $  57.99,356.25, 56.84, 10.44, 54.83, 23.37, 52.30, 34.71,
     $  49.62, 44.60, 47.16, 53.40, 45.20, 61.57, 43.88, 69.53/
C
      DATA((A(I,J, 22),I=1,2),J=1,36)/
     $  40.55, 77.09, 40.49, 85.49, 40.78, 94.31, 41.21,103.56,
     $  41.61,113.19, 41.88,123.10, 41.96,133.15, 41.90,143.25,
     $  41.76,153.36, 41.59,163.52, 41.36,173.73, 41.03,183.95,
     $  40.56,194.00, 40.00,203.71, 39.50,212.93, 39.22,221.68,
     $  39.34,230.06, 39.89,238.27, 40.86,246.51, 42.16,254.89,
     $  43.73,263.51, 45.52,272.43, 47.50,281.79, 49.61,291.74,
     $  51.75,302.53, 53.74,314.39, 55.32,327.46, 56.16,341.58,
     $  56.02,356.14, 54.82, 10.23, 52.72, 23.09, 50.04, 34.39,
     $  47.18, 44.23, 44.56, 52.97, 42.50, 61.10, 41.17, 69.03/
C
      DATA((A(I,J, 23),I=1,2),J=1,36)/
     $  37.83, 76.64, 37.90, 85.08, 38.33, 93.96, 38.91,103.29,
     $  39.42,113.01, 39.73,123.01, 39.83,133.12, 39.76,143.24,
     $  39.61,153.35, 39.43,163.47, 39.21,173.66, 38.90,183.87,
     $  38.44,193.94, 37.88,203.68, 37.37,212.95, 37.10,221.74,
     $  37.23,230.18, 37.83,238.48, 38.85,246.81, 40.18,255.31,
     $  41.74,264.03, 43.51,273.03, 45.47,282.42, 47.56,292.36,
     $  49.69,303.07, 51.69,314.79, 53.29,327.68, 54.17,341.62,
     $  54.04,356.02, 52.80, 10.03, 50.60, 22.84, 47.76, 34.10,
     $  44.71, 43.90, 41.90, 52.59, 39.72, 60.67, 38.37, 68.57/
C
      DATA((A(I,J, 24),I=1,2),J=1,36)/
     $  35.02, 76.24, 35.24, 84.71, 35.85, 93.65, 36.57,103.06,
     $  37.20,112.86, 37.58,122.93, 37.70,133.10, 37.61,143.25,
     $  37.44,153.34, 37.26,163.43, 37.06,173.59, 36.76,183.78,
     $  36.31,193.87, 35.76,203.64, 35.24,212.94, 34.98,221.78,
     $  35.15,230.28, 35.80,238.66, 36.86,247.09, 38.22,255.70,
     $  39.78,264.52, 41.53,273.61, 43.45,283.03, 45.51,292.96,
     $  47.63,303.59, 49.63,315.17, 51.26,327.88, 52.17,341.64,
     $  52.06,355.91, 50.79,  9.83, 48.49, 22.60, 45.47, 33.84,
     $  42.19, 43.60, 39.17, 52.24, 36.85, 60.27, 35.48, 68.16/
C
      DATA((A(I,J, 25),I=1,2),J=1,36)/
     $  32.13, 75.88, 32.52, 84.39, 33.32, 93.38, 34.22,102.85,
     $  34.97,112.73, 35.43,122.88, 35.55,133.10, 35.45,143.26,
     $  35.26,153.33, 35.07,163.39, 34.89,173.51, 34.62,183.69,
     $  34.19,193.77, 33.63,203.57, 33.12,212.91, 32.87,221.79,
     $  33.08,230.36, 33.78,238.82, 34.90,247.35, 36.29,256.07,
     $  37.86,265.00, 39.57,274.16, 41.45,283.62, 43.47,293.53,
     $  45.57,304.09, 47.58,315.54, 49.23,328.07, 50.18,341.65,
     $  50.09,355.78, 48.79,  9.63, 46.38, 22.37, 43.16, 33.60,
     $  39.64, 43.33, 36.36, 51.93, 33.88, 59.92, 32.48, 67.78/
C
      DATA((A(I,J, 26),I=1,2),J=1,36)/
     $  29.13, 75.55, 29.73, 84.11, 30.73, 93.15, 31.83,102.68,
     $  32.73,112.63, 33.26,122.84, 33.40,133.11, 33.29,143.28,
     $  33.07,153.34, 32.88,163.35, 32.71,173.44, 32.47,183.59,
     $  32.06,193.67, 31.51,203.48, 31.00,212.86, 30.77,221.79,
     $  31.02,230.42, 31.79,238.96, 32.96,247.60, 34.39,256.44,
     $  35.95,265.47, 37.63,274.70, 39.46,284.20, 41.44,294.09,
     $  43.51,304.58, 45.52,315.89, 47.20,328.25, 48.19,341.65,
     $  48.13,355.65, 46.80,  9.42, 44.27, 22.15, 40.85, 33.37,
     $  37.04, 43.08, 33.48, 51.64, 30.79, 59.59, 29.36, 67.43/
C
      DATA((A(I,J, 27),I=1,2),J=1,36)/
     $  26.01, 75.26, 26.84, 83.86, 28.09, 92.95, 29.40,102.53,
     $  30.46,112.55, 31.08,122.82, 31.25,133.13, 31.11,143.31,
     $  30.88,153.34, 30.68,163.32, 30.53,173.36, 30.32,183.48,
     $  29.93,193.56, 29.39,203.39, 28.88,212.80, 28.67,221.78,
     $  28.97,230.47, 29.81,239.10, 31.05,247.84, 32.51,256.79,
     $  34.06,265.92, 35.70,275.23, 37.49,284.76, 39.42,294.64,
     $  41.46,305.05, 43.46,316.24, 45.16,328.43, 46.20,341.64,
     $  46.17,355.50, 44.83,  9.21, 42.18, 21.93, 38.53, 33.15,
     $  34.40, 42.85, 30.48, 51.38, 27.54, 59.29, 26.38, 67.12/
C
      DATA((A(I,J, 28),I=1,2),J=1,36)/
     $  22.98, 75.01, 24.03, 83.65, 25.38, 92.79, 26.95,102.42,
     $  28.19,112.48, 28.90,122.81, 29.09,133.15, 28.93,143.33,
     $  28.68,153.34, 28.47,163.28, 28.34,173.29, 28.16,183.38,
     $  27.80,193.45, 27.28,203.29, 26.77,212.73, 26.59,221.75,
     $  26.94,230.51, 27.86,239.22, 29.17,248.07, 30.65,257.13,
     $  32.19,266.36, 33.79,275.74, 35.53,285.30, 37.41,295.17,
     $  39.41,305.52, 41.40,316.58, 43.13,328.59, 44.21,341.62,
     $  44.23,355.35, 42.86,  9.00, 40.10, 21.71, 36.21, 32.93,
     $  31.82, 42.62, 27.36, 51.13, 24.44, 59.01, 23.54, 66.84/
C
      DATA((A(I,J, 29),I=1,2),J=1,36)/
     $  20.04, 74.79, 21.31, 83.48, 22.74, 92.65, 24.45,102.32,
     $  25.89,112.43, 26.71,122.80, 26.92,133.17, 26.75,143.35,
     $  26.47,153.34, 26.26,163.25, 26.15,173.21, 26.00,183.27,
     $  25.68,193.33, 25.16,203.18, 24.67,212.65, 24.51,221.73,
     $  24.92,230.55, 25.92,239.35, 27.30,248.30, 28.81,257.47,
     $  30.34,266.80, 31.89,276.24, 33.57,285.83, 35.41,295.68,
     $  37.36,305.97, 39.34,316.91, 41.09,328.75, 42.23,341.60,
     $  42.29,355.19, 40.92,  8.78, 38.04, 21.48, 33.89, 32.72,
     $  29.31, 42.41, 24.38, 50.89, 21.46, 58.74, 20.82, 66.57/
C
      DATA((A(I,J, 30),I=1,2),J=1,36)/
     $  17.19, 74.59, 18.67, 83.34, 20.17, 92.55, 22.03,102.25,
     $  23.59,112.40, 24.51,122.81, 24.75,133.19, 24.56,143.37,
     $  24.26,153.34, 24.04,163.22, 23.95,173.14, 23.84,183.17,
     $  23.55,193.22, 23.05,203.07, 22.57,212.57, 22.45,221.70,
     $  22.92,230.60, 23.99,239.48, 25.44,248.53, 26.99,257.80,
     $  28.50,267.22, 30.00,276.72, 31.62,286.34, 33.41,296.19,
     $  35.32,306.42, 37.27,317.24, 39.05,328.91, 40.25,341.58,
     $  40.36,355.03, 38.99,  8.54, 35.99, 21.24, 31.56, 32.49,
     $  26.86, 42.19, 21.55, 50.67, 18.61, 58.49, 18.22, 66.33/
C
      DATA((A(I,J, 31),I=1,2),J=1,36)/
     $  14.43, 74.42, 16.11, 83.22, 17.66, 92.47, 19.67,102.20,
     $  21.27,112.39, 22.31,122.82, 22.57,133.21, 22.37,143.38,
     $  22.05,153.34, 21.82,163.19, 21.74,173.08, 21.67,183.07,
     $  21.42,193.10, 20.94,202.96, 20.49,212.49, 20.40,221.67,
     $  20.94,230.65, 22.08,239.62, 23.60,248.76, 25.19,258.13,
     $  26.67,267.64, 28.12,277.20, 29.68,286.84, 31.40,296.68,
     $  33.28,306.85, 35.21,317.56, 37.01,329.06, 38.27,341.55,
     $  38.44,354.85, 37.08,  8.30, 33.97, 20.98, 29.23, 32.26,
     $  24.47, 41.98, 18.85, 50.45, 15.87, 58.25, 15.74, 66.11/
C
      DATA((A(I,J, 32),I=1,2),J=1,36)/
     $  11.75, 74.28, 13.62, 83.14, 15.21, 92.42, 17.38,102.17,
     $  18.93,112.39, 20.10,122.84, 20.40,133.23, 20.18,143.39,
     $  19.83,153.33, 19.60,163.16, 19.54,173.02, 19.51,182.98,
     $  19.29,192.99, 18.84,202.85, 18.40,212.41, 18.36,221.65,
     $  18.97,230.71, 20.19,239.77, 21.78,249.00, 23.39,258.45,
     $  24.85,268.04, 26.25,277.66, 27.74,287.32, 29.41,297.15,
     $  31.23,307.27, 33.15,317.87, 34.97,329.22, 36.29,341.53,
     $  36.53,354.68, 35.18,  8.04, 31.97, 20.71, 26.91, 32.01,
     $  22.13, 41.77, 16.28, 50.22, 13.25, 57.96, 13.36, 65.88/
C
      DATA((A(I,J, 33),I=1,2),J=1,36)/
     $   9.16, 74.15, 11.21, 83.08, 12.82, 92.39, 15.14,102.16,
     $  16.56,112.40, 17.89,122.86, 18.21,133.24, 17.99,143.39,
     $  17.62,153.32, 17.38,163.13, 17.33,172.96, 17.34,182.90,
     $  17.16,192.89, 16.73,202.75, 16.33,212.34, 16.34,221.64,
     $  17.01,230.78, 18.31,239.93, 19.96,249.24, 21.59,258.78,
     $  23.03,268.44, 24.37,278.10, 25.81,287.78, 27.42,297.60,
     $  29.19,307.68, 31.09,318.18, 32.93,329.37, 34.32,341.50,
     $  34.63,354.50, 33.31,  7.77, 29.99, 20.43, 24.67, 31.74,
     $  19.85, 41.52, 13.83, 50.00, 10.73, 57.60, 11.09, 65.64/
C
      DATA((A(I,J, 34),I=1,2),J=1,36)/
     $   6.65, 74.02,  8.87, 83.03, 10.48, 92.38, 12.97,102.16,
     $  14.16,112.42, 15.67,122.89, 16.03,133.25, 15.79,143.38,
     $  15.41,153.30, 15.15,163.10, 15.12,172.91, 15.16,182.83,
     $  15.02,192.80, 14.63,202.66, 14.26,212.27, 14.32,221.64,
     $  15.06,230.87, 16.43,240.11, 18.14,249.50, 19.80,259.11,
     $  21.21,268.83, 22.50,278.54, 23.87,288.23, 25.44,298.05,
     $  27.16,308.09, 29.03,318.49, 30.90,329.53, 32.35,341.48,
     $  32.74,354.31, 31.45,  7.49, 28.04, 20.11, 22.50, 31.45,
     $  17.62, 41.26, 11.50, 49.49,  8.32, 57.24,  8.92, 65.40/
C
      DATA((A(I,J, 35),I=1,2),J=1,36)/
     $   4.21, 73.88,  6.59, 82.98,  8.20, 92.40, 10.84,102.19,
     $  11.83,112.45, 13.44,122.92, 13.82,133.25, 13.59,143.35,
     $  13.20,153.27, 12.93,163.07, 12.90,172.87, 12.98,182.76,
     $  12.88,192.71, 12.52,202.57, 12.19,212.22, 12.33,221.66,
     $  13.12,230.98, 14.56,240.30, 16.33,249.77, 18.00,259.44,
     $  19.38,269.21, 20.61,278.95, 21.93,288.66, 23.45,298.47,
     $  25.13,308.48, 26.97,318.79, 28.86,329.69, 30.38,341.46,
     $  30.86,354.13, 29.61,  7.20, 26.11, 19.78, 20.40, 31.13,
     $  15.44, 40.96,  9.28, 48.98,  6.00, 56.88,  6.83, 65.16/
C
      DATA((A(I,J, 36),I=1,2),J=1,36)/
     $   1.85, 73.75,  4.38, 82.94,  5.97, 92.43,  8.76,102.23,
     $   9.57,112.50, 11.21,122.95, 11.62,133.25, 11.39,143.33,
     $  10.99,153.23, 10.71,163.04, 10.68,172.83, 10.79,182.70,
     $  10.74,192.64, 10.42,202.50, 10.13,212.18, 10.33,221.70,
     $  11.18,231.11, 12.68,240.51, 14.51,250.04, 16.19,259.77,
     $  17.54,269.58, 18.72,279.35, 20.00,289.08, 21.47,298.88,
     $  23.10,308.86, 24.91,319.10, 26.82,329.85, 28.42,341.45,
     $  28.99,353.95, 27.78,  6.89, 24.21, 19.41, 18.37, 30.77,
     $  13.31, 40.63,  7.16, 48.48,  3.77, 56.52,  4.82, 64.92/
C
      DATA((A(I,J, 37),I=1,2),J=1,36)/
     $   0.23, 73.62,  2.23, 82.89,  3.79, 92.45,  6.72,102.29,
     $   7.36,112.56,  8.98,122.97,  9.42,133.24,  9.19,143.29,
     $   8.77,153.19,  8.48,163.00,  8.46,172.80,  8.60,182.66,
     $   8.60,192.57,  8.32,202.44,  8.07,212.17,  8.33,221.75,
     $   9.25,231.25, 10.81,240.73, 12.68,250.33, 14.37,260.10,
     $  15.68,269.95, 16.82,279.73, 18.05,289.47, 19.48,299.28,
     $  21.07,309.23, 22.86,319.40, 24.79,330.02, 26.46,341.45,
     $  27.11,353.78, 25.96,  6.58, 22.34, 19.03, 16.39, 30.37,
     $  11.22, 39.98,  5.14, 47.97,  1.62, 56.16,  2.79, 64.69/
C
      DATA((A(I,J, 38),I=1,2),J=1,36)/
     $  -1.38, 73.49, -0.26, 82.84,  1.44, 92.47,  4.73,102.36,
     $   5.20,112.62,  6.75,122.99,  7.23,133.21,  6.99,143.24,
     $   6.56,153.14,  6.27,162.96,  6.25,172.77,  6.40,182.63,
     $   6.45,192.52,  6.22,202.39,  6.02,212.16,  6.34,221.82,
     $   7.31,231.41,  8.93,240.97, 10.84,250.62, 12.54,260.43,
     $  13.81,270.30, 14.90,280.10, 16.11,289.85, 17.50,299.66,
     $  19.05,309.59, 20.81,319.69, 22.76,330.20, 24.50,341.46,
     $  25.24,353.61, 24.16,  6.26, 20.49, 18.61, 14.47, 29.93,
     $   9.19, 39.34,  3.20, 47.46,  0.36, 55.80,  0.75, 64.45/
C
      DATA((A(I,J, 39),I=1,2),J=1,36)/
     $  -2.91, 73.36, -2.74, 82.80, -0.90, 92.50,  1.96,102.43,
     $   3.08,112.66,  4.52,123.01,  5.03,133.18,  4.79,143.18,
     $   4.35,153.08,  4.09,162.92,  4.11,172.75,  4.19,182.60,
     $   4.30,192.48,  4.12,202.36,  4.00,212.18,  4.34,221.92,
     $   5.37,231.58,  7.05,241.22,  8.99,250.93, 10.68,260.76,
     $  11.92,270.65, 12.97,280.45, 14.17,290.22, 15.52,300.04,
     $  17.03,309.94, 18.77,319.99, 20.74,330.39, 22.54,341.49,
     $  23.38,353.45, 22.36,  5.93, 18.68, 18.17, 12.61, 29.43,
     $   7.19, 38.69,  1.50, 46.95, -0.90, 55.44, -1.19, 64.21/
C
      DATA((A(I,J, 40),I=1,2),J=1,36)/
     $  -4.69, 73.23, -5.15, 82.75, -3.19, 92.52, -0.81,102.49,
     $   0.96,112.70,  2.51,123.00,  2.84,133.14,  2.59,143.11,
     $   2.16,153.01,  1.91,162.87,  1.98,172.73,  2.19,182.59,
     $   2.31,192.46,  2.08,202.34,  1.97,212.21,  2.35,222.03,
     $   3.44,231.78,  5.16,241.49,  7.11,251.24,  8.81,261.09,
     $  10.02,270.98, 11.04,280.79, 12.22,290.57, 13.56,300.41,
     $  15.02,310.29, 16.73,320.28, 18.72,330.58, 20.58,341.53,
     $  21.50,353.30, 20.56,  5.59, 16.88, 17.70, 10.78, 28.90,
     $   5.24, 38.05, -0.19, 46.45, -0.97, 55.08, -3.01, 63.97/
C
      DATA((A(I,J, 41),I=1,2),J=1,36)/
     $  -6.47, 73.10, -7.30, 82.70, -5.32, 92.54, -3.54,102.56,
     $  -1.11,112.74,  0.51,122.96,  0.65,133.06,  0.39,143.03,
     $  -0.03,152.92, -0.27,162.81, -0.16,172.71,  0.18,182.60,
     $   0.32,192.47,  0.04,202.35, -0.05,212.28,  0.36,222.17,
     $   1.50,231.99,  3.24,241.77,  5.22,251.56,  6.91,261.42,
     $   8.10,271.31,  9.10,281.13, 10.27,290.92, 11.59,300.76,
     $  13.01,310.63, 14.69,320.57, 16.71,330.79, 18.63,341.59,
     $  19.62,353.17, 18.77,  5.25, 15.11, 17.21,  9.00, 28.33,
     $   3.34, 37.40, -1.78, 45.94, -1.91, 54.72, -4.83, 63.73/
C
      DATA((A(I,J, 42),I=1,2),J=1,36)/
     $  -8.45, 72.97, -9.45, 82.66, -7.45, 92.57, -5.83,102.62,
     $  -3.16,112.79, -1.49,122.93, -1.54,133.01, -1.81,142.93,
     $  -2.22,152.84, -2.47,162.77, -2.32,172.70, -1.83,182.61,
     $  -1.68,192.48, -1.99,202.35, -2.09,212.32, -1.62,222.30,
     $  -0.44,232.24,  1.33,242.06,  3.29,251.88,  4.99,261.74,
     $   6.17,271.63,  7.15,281.46,  8.31,291.26,  9.63,301.10,
     $  11.02,310.96, 12.66,320.86, 14.71,331.00, 16.67,341.67,
     $  17.74,353.04, 16.97,  4.92, 13.35, 16.69,  7.26, 27.67,
     $   1.93, 36.76, -3.35, 45.43, -2.84, 54.36, -6.50, 63.49/
C
      DATA((A(I,J, 43),I=1,2),J=1,36)/
     $ -10.38, 72.84,-11.30, 82.61, -9.39, 92.59, -8.13,102.69,
     $  -5.21,112.83, -3.61,122.98, -3.73,132.92, -4.01,142.82,
     $  -4.41,152.74, -4.66,162.70, -4.49,172.69, -3.94,182.60,
     $  -3.76,192.45, -4.06,202.37, -4.13,212.41, -3.62,222.46,
     $  -2.40,232.46, -0.62,242.36,  1.36,252.21,  3.03,262.07,
     $   4.21,271.95,  5.19,281.79,  6.35,291.60,  7.66,301.44,
     $   9.03,311.29, 10.65,321.15, 12.73,331.23, 14.72,341.77,
     $  15.84,352.94, 15.16,  4.58, 11.60, 16.16,  5.56, 26.95,
     $   0.53, 36.11, -4.93, 44.92, -4.64, 54.00, -8.13, 63.25/
C
      DATA((A(I,J, 44),I=1,2),J=1,36)/
     $ -12.26, 72.70,-13.11, 82.56,-11.30, 92.61, -9.97,102.80,
     $  -7.22,112.94, -5.73,122.93, -5.92,132.81, -6.20,142.69,
     $  -6.61,152.62, -6.87,162.63, -6.68,172.67, -6.06,182.61,
     $  -5.84,192.47, -6.13,202.41, -6.19,212.50, -5.61,222.64,
     $  -4.36,232.71, -2.58,242.67, -0.60,252.54,  1.06,262.40,
     $   2.22,272.27,  3.24,282.11,  4.39,291.93,  5.70,301.77,
     $   7.06,311.61,  8.64,321.46, 10.74,331.47, 12.76,341.89,
     $  13.91,352.85, 13.33,  4.25,  9.87, 15.61,  3.90, 26.24,
     $  -0.72, 35.46, -6.47, 44.42, -6.40, 53.64, -9.74, 63.01/
C
      DATA((A(I,J, 45),I=1,2),J=1,36)/
     $ -14.09, 72.57,-14.88, 82.52,-13.19, 92.66,-11.81,102.84,
     $  -9.24,112.94, -7.97,122.86, -8.10,132.68, -8.40,142.53,
     $  -8.82,152.48, -9.08,162.55, -8.87,172.65, -8.27,182.63,
     $  -8.01,192.51, -8.23,202.47, -8.25,212.61, -7.62,222.83,
     $  -6.33,232.97, -4.54,242.98, -2.59,252.88, -0.93,262.73,
     $   0.24,272.59,  1.29,282.44,  2.46,292.27,  3.80,302.10,
     $   5.08,311.93,  6.65,321.76,  8.76,331.72, 10.80,342.02,
     $  11.98,352.79, 11.48,  3.93,  8.14, 15.05,  2.18, 25.52,
     $  -2.16, 34.82, -7.96, 43.91, -8.14, 53.28,-11.34, 62.77/
C
      DATA((A(I,J, 46),I=1,2),J=1,36)/
     $ -15.87, 72.44,-16.61, 82.47,-15.05, 92.63,-13.64,102.85,
     $ -11.26,112.92,-10.21,122.76,-10.28,132.52,-10.59,142.36,
     $ -11.02,152.33,-11.28,162.45,-11.06,172.62,-10.48,182.65,
     $ -10.19,192.54,-10.34,202.54,-10.31,212.74, -9.65,223.03,
     $  -8.33,233.24, -6.54,243.31, -4.57,253.22, -2.95,263.06,
     $  -1.77,272.92, -0.67,282.78,  0.53,292.61,  1.89,302.44,
     $   3.15,312.26,  4.66,322.08,  6.79,331.99,  8.82,342.17,
     $  10.04,352.74,  9.60,  3.62,  6.42, 14.48,  0.45, 24.81,
     $  -3.61, 34.17, -9.43, 43.40, -9.85, 52.92,-12.92, 62.53/
C
      DATA((A(I,J, 47),I=1,2),J=1,36)/
     $ -17.62, 72.24,-18.32, 82.32,-16.88, 92.58,-15.47,102.83,
     $ -13.29,112.86,-12.45,122.63,-12.45,132.34,-12.78,142.15,
     $ -13.23,152.15,-13.48,162.34,-13.25,172.58,-12.69,182.66,
     $ -12.36,192.59,-12.44,202.62,-12.37,212.88,-11.68,223.24,
     $ -10.35,233.52, -8.56,243.64, -6.60,253.57, -4.96,263.41,
     $  -3.79,273.25, -2.65,283.12, -1.40,292.96, -0.01,302.79,
     $   1.21,312.60,  2.74,322.40,  4.83,332.27,  6.83,342.33,
     $   8.09,352.71,  7.71,  3.33,  4.69, 13.92, -1.20, 24.09,
     $  -5.29, 33.53,-10.87, 42.90,-11.55, 52.56,-14.50, 62.29/
C
      DATA((A(I,J, 48),I=1,2),J=1,36)/
     $ -19.32, 71.93,-20.00, 82.14,-18.70, 92.49,-17.30,102.77,
     $ -15.34,112.75,-14.66,122.46,-14.62,132.12,-14.96,141.92,
     $ -15.43,151.95,-15.68,162.22,-15.45,172.53,-14.90,182.67,
     $ -14.54,192.64,-14.55,202.71,-14.43,213.02,-13.73,223.46,
     $ -12.39,233.81,-10.60,243.97, -8.66,253.93, -7.02,263.76,
     $  -5.81,273.60, -4.63,283.48, -3.36,293.32, -1.94,303.13,
     $  -0.72,312.94,  0.82,322.74,  2.90,332.56,  4.84,342.52,
     $   6.13,352.70,  5.81,  3.05,  2.97, 13.37, -2.78, 23.38,
     $  -6.96, 32.88,-12.29, 42.39,-13.24, 52.20,-16.08, 61.94/
C
      DATA((A(I,J, 49),I=1,2),J=1,36)/
     $ -20.99, 71.58,-21.65, 81.92,-20.49, 92.36,-19.14,102.65,
     $ -17.42,112.60,-16.84,122.25,-16.78,131.86,-17.13,141.65,
     $ -17.62,151.73,-17.88,162.07,-17.65,172.46,-17.11,182.67,
     $ -16.73,192.70,-16.67,202.81,-16.51,213.18,-15.78,223.69,
     $ -14.44,234.11,-12.66,244.32,-10.73,254.30, -9.09,264.13,
     $  -7.86,273.97, -6.64,283.85, -5.31,293.69, -3.87,303.49,
     $  -2.65,313.28, -1.09,323.07,  0.97,332.86,  3.13,342.72,
     $   4.15,352.71,  3.90,  2.79,  1.25, 12.83, -4.36, 22.67,
     $  -8.60, 32.23,-13.71, 41.88,-14.89, 51.55,-17.65, 61.45/
C
      DATA((A(I,J, 50),I=1,2),J=1,36)/
     $ -22.62, 71.19,-23.28, 81.65,-22.27, 92.17,-20.98,102.48,
     $ -19.53,112.39,-19.01,121.98,-18.95,131.56,-19.31,141.35,
     $ -19.81,151.47,-20.07,161.89,-19.85,172.38,-19.32,182.66,
     $ -18.93,192.75,-18.82,202.92,-18.60,213.36,-17.85,223.94,
     $ -16.50,234.42,-14.73,244.67,-12.83,254.67,-11.19,264.51,
     $  -9.91,274.35, -8.65,284.24, -7.29,294.08, -5.84,303.86,
     $  -4.58,313.64, -3.01,323.42, -0.95,333.18,  1.41,343.02,
     $   2.61,352.90,  2.32,  2.72, -0.48, 12.30, -5.86, 21.94,
     $ -10.20, 31.50,-15.07, 41.10,-16.54, 50.87,-19.24, 60.91/
C
      DATA((A(I,J, 51),I=1,2),J=1,36)/
     $ -24.22, 70.75,-24.89, 81.34,-24.03, 91.94,-22.84,102.25,
     $ -21.67,112.11,-21.14,121.66,-21.10,131.20,-21.48,141.00,
     $ -21.99,151.18,-22.25,161.69,-22.05,172.27,-21.54,182.64,
     $ -21.14,192.80,-20.97,203.04,-20.70,213.54,-19.93,224.19,
     $ -18.57,234.74,-16.82,245.03,-14.95,255.06,-13.30,264.91,
     $ -11.98,274.76,-10.67,284.65, -9.27,294.49, -7.80,304.26,
     $  -6.51,314.02, -4.93,323.79, -2.87,333.51, -0.31,343.22,
     $   1.07,352.92,  0.75,  2.48, -2.23, 11.80, -7.37, 21.24,
     $ -11.76, 30.70,-16.43, 40.31,-18.21, 50.18,-20.86, 60.35/
C
      DATA((A(I,J, 52),I=1,2),J=1,36)/
     $ -25.80, 70.28,-26.48, 80.98,-25.78, 91.64,-24.70,101.95,
     $ -23.76,111.78,-23.25,121.28,-23.24,130.81,-23.64,140.62,
     $ -24.16,150.86,-24.44,161.45,-24.25,172.13,-23.77,182.59,
     $ -23.35,192.85,-23.13,203.16,-22.82,213.73,-22.02,224.46,
     $ -20.67,235.07,-18.93,245.41,-17.09,255.46,-15.43,265.34,
     $ -14.05,275.19,-12.69,285.08,-11.25,294.91, -9.76,304.67,
     $  -8.44,314.41, -6.86,324.17, -4.79,333.86, -2.17,343.42,
     $  -0.50,352.94, -0.83,  2.24, -3.97, 11.33, -8.90, 20.56,
     $ -13.32, 29.92,-17.81, 39.53,-19.89, 49.48,-22.50, 59.75/
C
      DATA((A(I,J, 53),I=1,2),J=1,36)/
     $ -27.35, 69.77,-28.06, 80.56,-27.52, 91.27,-26.58,101.58,
     $ -25.81,111.37,-25.34,120.84,-25.36,130.35,-25.79,140.19,
     $ -26.33,150.50,-26.62,161.18,-26.46,171.96,-25.99,182.53,
     $ -25.57,192.89,-25.31,203.29,-24.95,213.94,-24.13,224.73,
     $ -22.78,235.41,-21.05,245.80,-19.23,255.89,-17.56,265.79,
     $ -16.12,275.64,-14.72,285.53,-13.24,295.36,-11.72,305.10,
     $ -10.36,314.83, -8.77,324.57, -6.71,334.22, -4.04,343.69,
     $  -2.29,352.96, -2.60,  2.00, -5.74, 10.89,-10.44, 19.91,
     $ -14.87, 29.17,-19.21, 38.77,-21.60, 48.77,-24.18, 59.13/
C
      DATA((A(I,J, 54),I=1,2),J=1,36)/
     $ -28.87, 69.22,-29.62, 80.10,-29.24, 90.84,-28.47,101.14,
     $ -27.82,110.89,-27.40,120.33,-27.46,129.84,-27.93,139.71,
     $ -28.49,150.09,-28.79,160.87,-28.66,171.76,-28.23,182.45,
     $ -27.80,192.92,-27.49,203.42,-27.09,214.15,-26.26,225.02,
     $ -24.90,235.77,-23.19,246.21,-21.37,256.34,-19.69,266.26,
     $ -18.20,276.13,-16.75,286.01,-15.22,295.83,-13.68,305.55,
     $ -12.27,315.27,-10.67,324.98, -8.61,334.59, -6.05,343.96,
     $  -4.08,353.02, -4.37,  1.81, -7.52, 10.49,-12.02, 19.31,
     $ -16.44, 28.45,-20.64, 38.02,-23.31, 48.06,-25.88, 58.49/
C
      DATA((A(I,J, 55),I=1,2),J=1,36)/
     $ -30.37, 68.64,-31.16, 79.58,-30.94, 90.34,-30.38,100.62,
     $ -29.78,110.34,-29.43,119.76,-29.55,129.27,-30.05,139.19,
     $ -30.63,149.64,-30.96,160.52,-30.87,171.53,-30.47,182.35,
     $ -30.04,192.95,-29.69,203.56,-29.24,214.38,-28.39,225.32,
     $ -27.04,236.14,-25.33,246.64,-23.52,256.81,-21.82,266.76,
     $ -20.28,276.64,-18.78,286.52,-17.21,296.33,-15.64,306.05,
     $ -14.18,315.73,-12.56,325.42,-10.51,334.98, -8.07,344.25,
     $  -6.11,353.14, -6.35,  1.69, -9.32, 10.12,-13.63, 18.74,
     $ -18.02, 27.77,-22.11, 37.31,-25.03, 47.36,-27.62, 57.84/
C
      DATA((A(I,J, 56),I=1,2),J=1,36)/
     $ -31.85, 68.04,-32.69, 79.01,-32.62, 89.78,-32.22,100.02,
     $ -31.70,109.70,-31.43,119.11,-31.61,128.64,-32.15,138.60,
     $ -32.77,149.13,-33.13,160.12,-33.08,171.25,-32.71,182.22,
     $ -32.28,192.96,-31.90,203.70,-31.41,214.61,-30.53,225.65,
     $ -29.18,236.54,-27.48,247.10,-25.67,257.31,-23.95,267.29,
     $ -22.36,277.19,-20.81,287.06,-19.19,296.86,-17.59,306.56,
     $ -16.08,316.21,-14.45,325.87,-12.41,335.38,-10.04,344.55,
     $  -8.15,353.27, -8.34,  1.60,-11.13,  9.79,-15.27, 18.22,
     $ -19.61, 27.14,-23.60, 36.62,-26.80, 46.68,-29.41, 57.19/
C
      DATA((A(I,J, 57),I=1,2),J=1,36)/
     $ -33.30, 67.42,-34.19, 78.40,-34.29, 89.14,-34.00, 99.35,
     $ -33.56,109.00,-33.38,118.40,-33.64,127.95,-34.23,137.96,
     $ -34.89,148.57,-35.29,159.67,-35.28,170.94,-34.95,182.05,
     $ -34.53,192.96,-34.12,203.84,-33.58,214.87,-32.67,225.99,
     $ -31.32,236.95,-29.63,247.58,-27.82,257.84,-26.08,267.86,
     $ -24.44,277.77,-22.83,287.63,-21.18,297.42,-19.55,307.10,
     $ -17.99,316.73,-16.33,326.34,-14.31,335.80,-12.01,344.87,
     $ -10.20,353.42,-10.33,  1.53,-12.95,  9.50,-16.96, 17.76,
     $ -21.21, 26.55,-25.13, 35.98,-28.46, 46.02,-31.08, 56.54/
C
      DATA((A(I,J, 58),I=1,2),J=1,36)/
     $ -34.72, 66.77,-35.68, 77.74,-35.93, 88.44,-35.72, 98.60,
     $ -35.39,108.23,-35.31,117.62,-35.64,127.19,-36.29,137.26,
     $ -36.99,147.96,-37.44,159.17,-37.48,170.58,-37.20,181.86,
     $ -36.79,192.94,-36.35,203.98,-35.76,215.14,-34.83,226.35,
     $ -33.47,237.40,-31.78,248.09,-29.97,258.41,-28.20,268.46,
     $ -26.51,278.39,-24.85,288.24,-23.16,298.01,-21.50,307.67,
     $ -19.90,317.27,-18.21,326.85,-16.20,336.24,-13.96,345.20,
     $ -12.25,353.58,-12.33,  1.49,-14.78,  9.26,-18.64, 17.34,
     $ -22.82, 26.01,-26.72, 35.37,-30.04, 45.38,-32.68, 55.89/
C
      DATA((A(I,J, 59),I=1,2),J=1,36)/
     $ -36.13, 66.11,-37.16, 77.04,-37.52, 87.69,-37.40, 97.79,
     $ -37.17,107.38,-37.20,116.77,-37.62,126.37,-38.34,136.50,
     $ -39.09,147.29,-39.59,158.62,-39.68,170.18,-39.44,181.64,
     $ -39.05,192.91,-38.58,204.12,-37.95,215.42,-36.99,226.74,
     $ -35.62,237.87,-33.94,248.63,-32.12,259.01,-30.32,269.10,
     $ -28.58,279.04,-26.87,288.89,-25.14,298.64,-23.45,308.27,
     $ -21.81,317.85,-20.08,327.38,-18.08,336.70,-15.90,345.55,
     $ -14.28,353.77,-14.35,  1.48,-16.62,  9.06,-20.32, 16.97,
     $ -24.41, 25.52,-28.26, 34.81,-31.56, 44.76,-34.19, 55.25/
C
      DATA((A(I,J, 60),I=1,2),J=1,36)/
     $ -37.51, 65.43,-38.63, 76.30,-39.04, 86.87,-39.02, 96.91,
     $ -38.91,106.46,-39.06,115.85,-39.57,125.48,-40.36,135.67,
     $ -41.17,146.55,-41.72,158.01,-41.88,169.73,-41.69,181.38,
     $ -41.31,192.86,-40.83,204.27,-40.16,215.72,-39.16,227.15,
     $ -37.78,238.37,-36.09,249.22,-34.26,259.66,-32.43,269.79,
     $ -30.65,279.74,-28.88,289.58,-27.12,299.30,-25.40,308.92,
     $ -23.72,318.46,-21.96,327.94,-19.95,337.18,-17.84,345.90,
     $ -16.30,353.96,-16.35,  1.50,-18.48,  8.90,-22.00, 16.65,
     $ -25.98, 25.08,-29.75, 34.28,-33.02, 44.18,-35.63, 54.62/
C
      DATA((A(I,J, 61),I=1,2),J=1,36)/
     $ -38.90, 64.74,-40.03, 75.53,-40.51, 86.00,-40.59, 95.96,
     $ -40.61,105.47,-40.88,114.86,-41.50,124.53,-42.36,134.78,
     $ -43.23,145.75,-43.85,157.33,-44.07,169.22,-43.94,181.09,
     $ -43.58,192.79,-43.08,204.41,-42.37,216.03,-41.34,227.60,
     $ -39.94,238.92,-38.24,249.84,-36.40,260.35,-34.54,270.52,
     $ -32.70,280.48,-30.90,290.31,-29.10,300.01,-27.35,309.60,
     $ -25.62,319.11,-23.82,328.52,-21.82,337.67,-19.77,346.27,
     $ -18.31,354.18,-18.36,  1.54,-20.33,  8.78,-23.68, 16.38,
     $ -27.52, 24.69,-31.21, 33.80,-34.42, 43.62,-37.02, 54.01/
C
      DATA((A(I,J, 62),I=1,2),J=1,36)/
     $ -40.22, 64.04,-41.38, 74.72,-41.93, 85.08,-42.12, 94.96,
     $ -42.27,104.42,-42.66,113.81,-43.39,123.50,-44.34,133.81,
     $ -45.28,144.88,-45.97,156.59,-46.27,168.66,-46.19,180.75,
     $ -45.86,192.70,-45.34,204.56,-44.59,216.37,-43.53,228.08,
     $ -42.10,239.51,-40.40,250.52,-38.53,261.09,-36.63,271.30,
     $ -34.76,281.28,-32.90,291.09,-31.07,300.77,-29.29,310.32,
     $ -27.53,319.79,-25.69,329.14,-23.69,338.18,-21.70,346.65,
     $ -20.31,354.41,-20.35,  1.62,-22.19,  8.70,-25.37, 16.17,
     $ -29.06, 24.35,-32.65, 33.36,-35.80, 43.09,-38.35, 53.40/
C
      DATA((A(I,J, 63),I=1,2),J=1,36)/
     $ -41.50, 63.33,-42.68, 73.88,-43.30, 84.12,-43.60, 93.89,
     $ -43.89,103.31,-44.42,112.68,-45.25,122.40,-46.29,132.77,
     $ -47.31,143.93,-48.08,155.78,-48.45,168.04,-48.44,180.37,
     $ -48.14,192.60,-47.60,204.71,-46.82,216.73,-45.72,228.60,
     $ -44.27,240.15,-42.54,251.26,-40.66,261.89,-38.72,272.14,
     $ -36.80,282.12,-34.91,291.92,-33.04,301.57,-31.22,311.09,
     $ -29.42,320.52,-27.55,329.79,-25.56,338.72,-23.62,347.05,
     $ -22.31,354.66,-22.34,  1.72,-24.06,  8.66,-27.05, 16.00,
     $ -30.58, 24.06,-34.06, 32.96,-37.14, 42.59,-39.65, 52.80/
C
      DATA((A(I,J, 64),I=1,2),J=1,36)/
     $ -42.74, 62.61,-43.95, 73.01,-44.64, 83.11,-45.06, 92.78,
     $ -45.48,102.13,-46.14,111.49,-47.09,121.22,-48.22,131.65,
     $ -49.32,142.89,-50.17,154.89,-50.63,167.35,-50.69,179.95,
     $ -50.42,192.47,-49.88,204.86,-49.06,217.12,-47.91,229.16,
     $ -46.43,240.85,-44.68,252.05,-42.77,262.75,-40.80,273.04,
     $ -38.84,283.03,-36.91,292.81,-35.01,302.42,-33.15,311.91,
     $ -31.31,321.28,-29.41,330.46,-27.43,339.27,-25.55,347.46,
     $ -24.30,354.92,-24.33,  1.85,-25.92,  8.67,-28.74, 15.88,
     $ -32.10, 23.82,-35.45, 32.60,-38.45, 42.12,-40.91, 52.21/
C
      DATA((A(I,J, 65),I=1,2),J=1,36)/
     $ -43.95, 61.87,-45.18, 72.11,-45.95, 82.06,-46.47, 91.61,
     $ -47.03,100.89,-47.82,110.22,-48.89,119.97,-50.12,130.44,
     $ -51.31,141.77,-52.26,153.91,-52.81,166.59,-52.93,179.48,
     $ -52.70,192.32,-52.15,205.02,-51.30,217.54,-50.11,229.78,
     $ -48.59,241.61,-46.81,252.92,-44.87,263.68,-42.87,274.01,
     $ -40.87,284.00,-38.90,293.76,-36.96,303.34,-35.07,312.78,
     $ -33.19,322.08,-31.27,331.16,-29.29,339.84,-27.48,347.88,
     $ -26.29,355.21,-26.30,  2.01,-27.78,  8.71,-30.42, 15.80,
     $ -33.61, 23.62,-36.83, 32.27,-39.73, 41.67,-42.13, 51.62/
C
      DATA((A(I,J, 66),I=1,2),J=1,36)/
     $ -45.13, 61.11,-46.39, 71.18,-47.22, 80.97,-47.86, 90.39,
     $ -48.56, 99.59,-49.48,108.88,-50.66,118.63,-51.99,129.13,
     $ -53.28,140.55,-54.33,152.84,-54.97,165.75,-55.18,178.94,
     $ -54.98,192.14,-54.43,205.19,-53.54,218.00,-52.31,230.46,
     $ -50.76,242.45,-48.94,253.86,-46.96,264.70,-44.93,275.05,
     $ -42.89,285.04,-40.88,294.78,-38.91,304.32,-36.98,313.70,
     $ -35.06,322.92,-33.12,331.89,-31.16,340.43,-29.40,348.33,
     $ -28.27,355.52,-28.27,  2.20,-29.64,  8.79,-32.10, 15.77,
     $ -35.12, 23.47,-38.20, 31.99,-41.00, 41.24,-43.34, 51.04/
C
      DATA((A(I,J, 67),I=1,2),J=1,36)/
     $ -46.29, 60.34,-47.57, 70.21,-48.48, 79.83,-49.23, 89.12,
     $ -50.05, 98.23,-51.10,107.47,-52.39,117.20,-53.83,127.72,
     $ -55.23,139.22,-56.38,151.66,-57.13,164.82,-57.41,178.35,
     $ -57.26,191.94,-56.71,205.37,-55.80,218.51,-54.52,231.22,
     $ -52.92,243.37,-51.06,254.90,-49.04,265.80,-46.97,276.18,
     $ -44.90,286.17,-42.85,295.87,-40.85,305.36,-38.88,314.68,
     $ -36.93,323.80,-34.97,332.65,-33.03,341.04,-31.32,348.79,
     $ -30.24,355.84,-30.23,  2.41,-31.49,  8.91,-33.79, 15.79,
     $ -36.63, 23.36,-39.56, 31.73,-42.26, 40.83,-44.52, 50.45/
C
      DATA((A(I,J, 68),I=1,2),J=1,36)/
     $ -47.43, 59.55,-48.74, 69.21,-49.72, 78.64,-50.58, 87.78,
     $ -51.52, 96.79,-52.69,105.97,-54.10,115.67,-55.64,126.20,
     $ -57.15,137.76,-58.41,150.35,-59.26,163.77,-59.64,177.67,
     $ -59.54,191.70,-59.00,205.57,-58.05,219.07,-56.72,232.06,
     $ -55.07,244.40,-53.17,256.04,-51.12,267.01,-49.00,277.40,
     $ -46.89,287.37,-44.81,297.04,-42.77,306.48,-40.77,315.71,
     $ -38.79,324.73,-36.82,333.44,-34.90,341.67,-33.25,349.26,
     $ -32.21,356.19,-32.19,  2.66,-33.35,  9.07,-35.47, 15.84,
     $ -38.14, 23.29,-40.92, 31.51,-43.50, 40.44,-45.69, 49.87/
C
      DATA((A(I,J, 69),I=1,2),J=1,36)/
     $ -48.56, 58.74,-49.89, 68.18,-50.94, 77.41,-51.90, 86.40,
     $ -52.97, 95.29,-54.25,104.38,-55.77,114.03,-57.42,124.55,
     $ -59.03,136.16,-60.40,148.90,-61.38,162.59,-61.86,176.91,
     $ -61.81,191.43,-61.28,205.78,-60.30,219.71,-58.92,233.00,
     $ -57.22,245.54,-55.28,257.30,-53.19,268.33,-51.03,278.74,
     $ -48.88,288.69,-46.76,298.30,-44.68,307.66,-42.65,316.80,
     $ -40.64,325.70,-38.66,334.26,-36.77,342.32,-35.17,349.76,
     $ -34.18,356.56,-34.15,  2.94,-35.20,  9.26,-37.16, 15.93,
     $ -39.65, 23.25,-42.27, 31.31,-44.73, 40.06,-46.85, 49.28/
C
      DATA((A(I,J, 70),I=1,2),J=1,36)/
     $ -49.69, 57.90,-51.03, 67.11,-52.14, 76.13,-53.21, 84.95,
     $ -54.39, 93.71,-55.79,102.70,-57.41,112.28,-59.16,122.77,
     $ -60.88,134.40,-62.38,147.28,-63.48,161.27,-64.06,176.04,
     $ -64.08,191.11,-63.56,206.02,-62.55,220.42,-61.12,234.06,
     $ -59.36,246.82,-57.37,258.71,-55.23,269.79,-53.04,280.21,
     $ -50.85,290.12,-48.69,299.66,-46.59,308.94,-44.52,317.96,
     $ -42.49,326.72,-40.51,335.11,-38.65,343.00,-37.10,350.28,
     $ -36.15,356.96,-36.10,  3.24,-37.05,  9.48,-38.85, 16.06,
     $ -41.16, 23.25,-43.63, 31.14,-45.96, 39.68,-48.01, 48.68/
C
      DATA((A(I,J, 71),I=1,2),J=1,36)/
     $ -50.80, 57.04,-52.16, 66.00,-53.34, 74.80,-54.50, 83.43,
     $ -55.78, 92.04,-57.29,100.91,-59.01,110.39,-60.87,120.82,
     $ -62.71,132.46,-64.33,145.46,-65.56,159.76,-66.25,175.03,
     $ -66.34,190.72,-65.83,206.30,-64.80,221.24,-63.32,235.27,
     $ -61.50,248.28,-59.45,260.28,-57.26,271.41,-55.03,281.82,
     $ -52.80,291.68,-50.61,301.14,-48.47,310.30,-46.38,319.19,
     $ -44.33,327.78,-42.36,335.99,-40.53,343.70,-39.03,350.82,
     $ -38.13,357.38,-38.05,  3.58,-38.90,  9.74,-40.54, 16.22,
     $ -42.67, 23.27,-44.98, 30.99,-47.19, 39.31,-49.15, 48.07/
C
      DATA((A(I,J, 72),I=1,2),J=1,36)/
     $ -51.92, 56.15,-53.29, 64.86,-54.53, 73.42,-55.78, 81.84,
     $ -57.16, 90.29,-58.76, 99.01,-60.58,108.36,-62.54,118.68,
     $ -64.49,130.28,-66.24,143.40,-67.61,158.02,-68.42,173.84,
     $ -68.59,190.26,-68.11,206.57,-67.06,222.18,-65.50,236.68,
     $ -63.62,249.94,-61.51,262.07,-59.27,273.22,-56.99,283.59,
     $ -54.73,293.37,-52.51,302.73,-50.34,311.76,-48.23,320.49,
     $ -46.17,328.91,-44.21,336.92,-42.42,344.44,-40.97,351.40,
     $ -40.10,357.84,-40.00,  3.94,-40.75, 10.03,-42.24, 16.41,
     $ -44.20, 23.32,-46.34, 30.85,-48.42, 38.94,-50.30, 47.45/
C
      DATA((A(I,J, 73),I=1,2),J=1,36)/
     $ -53.04, 55.24,-54.43, 63.66,-55.72, 71.97,-57.05, 80.18,
     $ -58.52, 88.42,-60.21, 96.97,-62.11,106.15,-64.16,116.33,
     $ -66.22,127.84,-68.11,141.04,-69.62,155.99,-70.56,172.44,
     $ -70.82,189.73,-70.37,206.95,-69.29,223.30,-67.70,238.32,
     $ -65.72,251.87,-63.55,264.10,-61.26,275.25,-58.93,285.56,
     $ -56.63,295.23,-54.38,304.46,-52.19,313.32,-50.06,321.87,
     $ -48.00,330.09,-46.06,337.90,-44.31,345.22,-42.92,352.01,
     $ -42.07,358.32,-41.95,  4.34,-42.60, 10.34,-43.94, 16.62,
     $ -45.72, 23.38,-47.70, 30.72,-49.66, 38.57,-51.46, 46.81/
C
      DATA((A(I,J, 74),I=1,2),J=1,36)/
     $ -54.16, 54.28,-55.57, 62.41,-56.91, 70.45,-58.30, 78.42,
     $ -59.85, 86.44,-61.61, 94.78,-63.60,103.75,-65.74,113.72,
     $ -67.90,125.10,-69.92,138.32,-71.58,153.58,-72.67,170.78,
     $ -73.01,189.19,-72.60,207.48,-71.51,224.69,-69.85,240.29,
     $ -67.82,254.14,-65.56,266.43,-63.21,277.55,-60.84,287.75,
     $ -58.50,297.29,-56.22,306.33,-54.01,315.01,-51.88,323.35,
     $ -49.83,331.34,-47.91,338.92,-46.21,346.03,-44.86,352.66,
     $ -44.04,358.84,-43.89,  4.77,-44.46, 10.69,-45.65, 16.85,
     $ -47.26, 23.46,-49.08, 30.59,-50.91, 38.19,-52.62, 46.15/
C
      DATA((A(I,J, 75),I=1,2),J=1,36)/
     $ -55.30, 53.27,-56.71, 61.10,-58.09, 68.86,-59.54, 76.56,
     $ -61.16, 84.34,-62.99, 92.43,-65.04,101.13,-67.25,110.82,
     $ -69.52,122.00,-71.68,135.14,-73.49,150.71,-74.72,168.83,
     $ -75.16,188.53,-74.76,208.23,-73.61,226.49,-71.97,242.68,
     $ -69.86,256.82,-67.54,269.18,-65.12,280.16,-62.71,290.21,
     $ -60.34,299.55,-58.04,308.38,-55.81,316.83,-53.68,324.92,
     $ -51.64,332.67,-49.76,340.01,-48.10,346.90,-46.81,353.35,
     $ -46.01,359.40,-45.84,  5.23,-46.31, 11.05,-47.36, 17.10,
     $ -48.81, 23.55,-50.47, 30.46,-52.17, 37.80,-53.80, 45.46/
C
      DATA((A(I,J, 76),I=1,2),J=1,36)/
     $ -56.45, 52.22,-57.86, 59.72,-59.27, 67.17,-60.77, 74.59,
     $ -62.44, 82.09,-64.33, 89.88,-66.43, 98.25,-68.71,107.61,
     $ -71.07,118.45,-73.34,131.37,-75.32,147.24,-76.73,166.24,
     $ -77.30,187.55,-76.92,209.06,-75.72,228.65,-73.94,245.54,
     $ -71.85,260.04,-69.46,272.36,-66.99,283.19,-64.53,292.97,
     $ -62.14,302.06,-59.81,310.63,-57.59,318.80,-55.46,326.62,
     $ -53.45,334.09,-51.61,341.17,-50.00,347.84,-48.76,354.09,
     $ -47.98,  0.01,-47.78,  5.73,-48.17, 11.45,-49.08, 17.37,
     $ -50.37, 23.64,-51.88, 30.32,-53.45, 37.38,-54.99, 44.73/
C
      DATA((A(I,J, 77),I=1,2),J=1,36)/
     $ -57.62, 51.10,-59.02, 58.27,-60.45, 65.39,-61.99, 72.49,
     $ -63.71, 79.67,-65.63, 87.12,-67.77, 95.09,-70.10,104.01,
     $ -72.53,114.35,-74.92,126.98,-77.08,142.85,-78.69,162.74,
     $ -79.42,186.12,-79.08,210.11,-77.81,231.47,-75.91,249.12,
     $ -73.68,263.70,-71.30,276.11,-68.79,286.66,-66.30,296.11,
     $ -63.88,304.86,-61.55,313.10,-59.32,320.95,-57.22,328.45,
     $ -55.24,335.62,-53.45,342.42,-51.90,348.84,-50.70,354.90,
     $ -49.95,  0.66,-49.72,  6.26,-50.02, 11.86,-50.80, 17.64,
     $ -51.94, 23.72,-53.30, 30.16,-54.75, 36.93,-56.20, 43.95/
C
      DATA((A(I,J, 78),I=1,2),J=1,36)/
     $ -58.81, 49.91,-60.19, 56.72,-61.63, 63.49,-63.20, 70.24,
     $ -64.94, 77.06,-66.87, 84.08,-69.04, 91.60,-71.41, 99.96,
     $ -73.87,109.68,-76.38,121.71,-78.72,137.22,-80.57,157.87,
     $ -81.52,183.93,-81.22,211.60,-79.86,235.34,-77.82,253.78,
     $ -75.47,268.27,-73.01,280.36,-70.49,290.67,-67.99,299.69,
     $ -65.56,307.99,-63.24,315.83,-61.03,323.30,-58.95,330.44,
     $ -57.02,337.27,-55.28,343.77,-53.79,349.93,-52.64,355.77,
     $ -51.91,  1.37,-51.65,  6.82,-51.88, 12.29,-52.54, 17.91,
     $ -53.53, 23.79,-54.75, 29.97,-56.08, 36.44,-57.44, 43.12/
C
      DATA((A(I,J, 79),I=1,2),J=1,36)/
     $ -60.01, 48.64,-61.37, 55.07,-62.82, 61.46,-64.39, 67.82,
     $ -66.13, 74.22,-68.07, 80.78,-70.25, 87.74,-72.61, 95.39,
     $ -75.11,104.33,-77.70,115.32,-80.21,129.88,-82.34,150.69,
     $ -83.57,180.36,-83.35,213.97,-81.83,241.04,-79.63,260.04,
     $ -77.16,274.07,-74.61,285.39,-72.09,295.35,-69.58,303.76,
     $ -67.17,311.53,-64.87,318.86,-62.69,325.88,-60.65,332.61,
     $ -58.77,339.07,-57.10,345.24,-55.67,351.12,-54.58,356.73,
     $ -53.86,  2.13,-53.58,  7.43,-53.73, 12.74,-54.28, 18.18,
     $ -55.14, 23.84,-56.22, 29.75,-57.43, 35.90,-58.70, 42.23/
C
      DATA((A(I,J, 80),I=1,2),J=1,36)/
     $ -61.24, 47.27,-62.57, 53.29,-64.00, 59.26,-65.57, 65.20,
     $ -67.29, 71.13,-69.22, 77.16,-71.37, 83.46,-73.68, 90.33,
     $ -76.20, 98.17,-78.84,107.65,-81.48,120.26,-83.91,139.73,
     $ -85.56,173.55,-85.44,218.43,-83.67,250.05,-81.26,268.71,
     $ -78.68,281.48,-76.09,291.61,-73.54,300.43,-71.06,308.40,
     $ -68.68,315.49,-66.42,322.24,-64.29,328.74,-62.31,335.00,
     $ -60.50,341.04,-58.89,346.85,-57.54,352.42,-56.49,357.78,
     $ -55.80,  2.97,-55.50,  8.08,-55.59, 13.21,-56.03, 18.44,
     $ -56.76, 23.86,-57.71, 29.48,-58.80, 35.30,-59.99, 41.25/
C
      DATA((A(I,J, 81),I=1,2),J=1,36)/
     $ -62.50, 45.77,-63.78, 51.35,-65.18, 56.88,-66.70, 62.34,
     $ -68.40, 67.74,-70.30, 73.16,-72.40, 78.69,-74.65, 84.66,
     $ -77.12, 91.09,-79.74, 98.50,-82.44,107.89,-85.11,122.55,
     $ -87.38,156.68,-87.44,229.90,-85.23,265.48,-82.61,280.81,
     $ -79.97,290.96,-77.37,299.16,-74.85,306.58,-72.39,313.70,
     $ -70.07,319.95,-67.88,326.01,-65.83,331.90,-63.93,337.65,
     $ -62.20,343.23,-60.67,348.63,-59.39,353.86,-58.40,358.93,
     $ -57.73,  3.88,-57.41,  8.78,-57.44, 13.69,-57.78, 18.70,
     $ -58.40, 23.85,-59.23, 29.16,-60.21, 34.62,-61.30, 40.18/
C
      DATA((A(I,J, 82),I=1,2),J=1,36)/
     $ -63.77, 44.12,-65.00, 49.24,-66.34, 54.28,-67.82, 59.20,
     $ -69.47, 64.03,-71.30, 68.75,-73.28, 73.54,-75.46, 78.34,
     $ -77.83, 83.12,-80.34, 87.99,-82.96, 93.01,-85.65, 98.34,
     $ -88.38,105.23,-88.88,283.00,-86.17,291.25,-83.50,297.05,
     $ -80.90,302.64,-78.38,308.20,-75.94,313.77,-73.60,319.41,
     $ -71.34,324.97,-69.24,330.21,-67.29,335.43,-65.49,340.58,
     $ -63.85,345.65,-62.42,350.61,-61.22,355.47,-60.28,  0.22,
     $ -59.64,  4.89,-59.31,  9.53,-59.28, 14.20,-59.55, 18.95,
     $ -60.06, 23.80,-60.77, 28.77,-61.65, 33.84,-62.66, 38.97/
C
      DATA((A(I,J, 83),I=1,2),J=1,36)/
     $ -65.07, 42.29,-66.22, 46.90,-67.49, 51.40,-68.90, 55.75,
     $ -70.47, 59.92,-72.20, 63.89,-74.06, 67.84,-76.10, 71.37,
     $ -78.29, 74.42,-80.60, 76.61,-82.97, 77.11,-85.33, 73.14,
     $ -87.41, 53.44,-87.84,353.85,-86.05,322.75,-83.75,316.21,
     $ -81.39,316.19,-79.06,318.53,-76.79,321.99,-74.59,326.06,
     $ -72.44,330.57,-70.48,334.90,-68.65,339.35,-66.97,343.85,
     $ -65.46,348.36,-64.13,352.83,-63.01,357.27,-62.14,  1.65,
     $ -61.53,  6.00,-61.20, 10.35,-61.13, 14.73,-61.32, 19.17,
     $ -61.74, 23.68,-62.35, 28.27,-63.12, 32.93,-64.04, 37.62/
C
      DATA((A(I,J, 84),I=1,2),J=1,36)/
     $ -66.38, 40.24,-67.44, 44.30,-68.62, 48.22,-69.94, 51.93,
     $ -71.39, 55.40,-72.97, 58.67,-74.68, 61.59,-76.53, 63.85,
     $ -78.48, 65.21,-80.48, 65.09,-82.47, 62.31,-84.30, 54.36,
     $ -85.65, 36.57,-85.94,  8.72,-84.98,345.84,-83.30,334.54,
     $ -81.36,330.34,-79.34,329.75,-77.32,331.06,-75.34,333.48,
     $ -73.42,336.61,-71.58,340.10,-69.91,343.71,-68.37,347.50,
     $ -66.99,351.39,-65.79,355.33,-64.77,359.29,-63.97,  3.26,
     $ -63.40,  7.24,-63.07, 11.24,-62.98, 15.27,-63.10, 19.35,
     $ -63.44, 23.49,-63.95, 27.66,-64.63, 31.87,-65.44, 36.07/
C
      DATA((A(I,J, 85),I=1,2),J=1,36)/
     $ -67.70, 37.91,-68.65, 41.37,-69.73, 44.65,-70.92, 47.69,
     $ -72.22, 50.41,-73.62, 52.97,-75.13, 54.86,-76.73, 55.95,
     $ -78.37, 55.94,-80.01, 54.26,-81.56, 50.10,-82.88, 42.18,
     $ -83.75, 29.63,-83.95, 13.88,-83.41,359.31,-82.29,349.20,
     $ -80.84,343.49,-79.21,340.97,-77.52,340.54,-75.83,341.49,
     $ -74.16,343.35,-72.53,345.80,-71.04,348.55,-69.68,351.57,
     $ -68.46,354.80,-67.38,358.15,-66.49,  1.59,-65.78,  5.08,
     $ -65.25,  8.63,-64.94, 12.21,-64.82, 15.84,-64.90, 19.50,
     $ -65.16, 23.20,-65.59, 26.91,-66.16, 30.64,-66.86, 34.31/
C
      DATA((A(I,J, 86),I=1,2),J=1,36)/
     $ -69.03, 35.23,-69.85, 38.05,-70.78, 40.66,-71.81, 42.99,
     $ -72.92, 45.11,-74.12, 46.76,-75.38, 47.76,-76.68, 47.92,
     $ -77.99, 47.03,-79.24, 44.70,-80.36, 40.56,-81.26, 34.25,
     $ -81.83, 25.91,-81.97, 16.39,-81.64,  7.23,-80.92,359.78,
     $ -79.90,354.56,-78.69,351.41,-77.38,349.97,-76.02,349.80,
     $ -74.65,350.56,-73.31,352.00,-72.02,353.89,-70.87,356.13,
     $ -69.83,358.64,-68.92,  1.35,-68.15,  4.20,-67.53,  7.16,
     $ -67.07, 10.20,-66.78, 13.30,-66.66, 16.45,-66.70, 19.62,
     $ -66.89, 22.82,-67.23, 26.00,-67.71, 29.16,-68.31, 32.25/
C
      DATA((A(I,J, 87),I=1,2),J=1,36)/
     $ -70.35, 32.13,-71.02, 34.27,-71.77, 36.17,-72.60, 37.87,
     $ -73.49, 39.29,-74.44, 40.16,-75.41, 40.47,-76.39, 40.06,
     $ -77.34, 38.82,-78.21, 36.58,-78.96, 33.24,-79.55, 28.83,
     $ -79.90, 23.55,-79.98, 17.82,-79.80, 12.21,-79.35,  7.28,
     $ -78.68,  3.35,-77.86,  0.55,-76.92,358.82,-75.92,358.04,
     $ -74.89,358.03,-73.87,358.66,-72.87,359.75,-71.93,  1.19,
     $ -71.10,  2.97,-70.37,  4.99,-69.75,  7.19,-69.25,  9.53,
     $ -68.87, 11.98,-68.62, 14.50,-68.50, 17.07,-68.52, 19.67,
     $ -68.66, 22.27,-68.92, 24.85,-69.29, 27.38,-69.77, 29.82/
C
      DATA((A(I,J, 88),I=1,2),J=1,36)/
     $ -71.65, 28.52,-72.13, 29.94,-72.68, 31.25,-73.27, 32.29,
     $ -73.90, 32.99,-74.55, 33.31,-75.21, 33.20,-75.85, 32.61,
     $ -76.46, 31.48,-77.00, 29.81,-77.44, 27.59,-77.78, 24.91,
     $ -77.97, 21.88,-78.02, 18.70,-77.92, 15.55,-77.66, 12.66,
     $ -77.27, 10.18,-76.78,  8.19,-76.19,  6.77,-75.55,  5.89,
     $ -74.87,  5.52,-74.19,  5.60,-73.51,  6.06,-72.86,  6.83,
     $ -72.25,  7.85,-71.73,  9.15,-71.29, 10.64,-70.92, 12.28,
     $ -70.64, 14.03,-70.45, 15.85,-70.35, 17.73,-70.35, 19.64,
     $ -70.44, 21.54,-70.62, 23.41,-70.89, 25.22,-71.23, 26.94/
C
      DATA((A(I,J, 89),I=1,2),J=1,36)/
     $ -72.92, 24.43,-73.19, 25.16,-73.49, 25.74,-73.80, 26.14,
     $ -74.13, 26.35,-74.46, 26.36,-74.78, 26.16,-75.10, 25.73,
     $ -75.38, 25.07,-75.62, 24.20,-75.83, 23.14,-75.97, 21.93,
     $ -76.06, 20.61,-76.08, 19.25,-76.03, 17.89,-75.91, 16.60,
     $ -75.75, 15.45,-75.52, 14.46,-75.25, 13.68,-74.94, 13.10,
     $ -74.62, 12.76,-74.28, 12.63,-73.94, 12.72,-73.61, 12.98,
     $ -73.30, 13.43,-73.01, 14.02,-72.76, 14.74,-72.55, 15.56,
     $ -72.38, 16.44,-72.27, 17.44,-72.22, 18.48,-72.21, 19.53,
     $ -72.26, 20.58,-72.35, 21.61,-72.50, 22.63,-72.69, 23.59/
C
C 
C******************************************************************* 
C  SAVE ORIGINAL INPUTS
C******************************************************************* 
      GGLAT=OLDLAT 
      GGLON=OLDLON 
C******************************************************************* 
C     REDUCE GGLAT TO THE RANGE -90 TO +90 DEGREES
C******************************************************************* 
 6000 IF(GGLAT.LE.90.) GO TO 6001
      GGLAT=180.-GGLAT
      GGLON=GGLON+180.
      GO TO 6000
 6001 IF(GGLAT.GE.-90.) GO TO 6002
      GGLAT=-180.-GGLAT
      GGLON=GGLON+180.
      GO TO 6000
 6002 CONTINUE
C***********************************************************************
C     REDUCE GGLON TO .LT. 360 DEGREES (POSITIVE OR NEGATIVE) 
C***********************************************************************
 6666 GGLON = AMOD(GGLON,360.)
C***********************************************************************
C     CHECK TO SEE IF GGLON .GT.0, IF NOT CORRECT TO BE .GT. ZERO
C***********************************************************************
      IF(GGLON .LT. 0.0)GGLON = GGLON + 360.0
      I = IFIX((90.0 - GGLAT)/2.0)
      J = IFIX(GGLON/10.) + 1
C***********************************************************************
C     CHECK TO SEE IF I IS WITHIN BOUNDS
C***********************************************************************
      IF(I.GT.0.AND.I.LT.89)GO TO 3 
C***********************************************************************
C     SET TO INTERPOLATE TO THE POLES (N OR S GEOGRAPHIC)
C***********************************************************************
      IF (J .GT. 36) J=J-36
      IF (J .LT.  1) J=J+36
      K=J+1
      IF (K .GT. 36) K=K-36
      IF (I .GT.  0) GO TO 2 
        I=0
        X1LAT=CGMNLA
        X1LON=CGMNLO
        X2LAT=A(1,J,I+1)
        X2LON=A(2,J,I+1)
        X3LAT=A(1,K,I+1)
        X3LON=A(2,K,I+1)
        X4LAT=CGMNLA
        X4LON=CGMNLO
        GO TO 5
    2 I=89
      X1LAT=A(1,J,I)
      X1LON=A(2,J,I)
      X2LAT=CGMSLA 
      X2LON=CGMSLO 
      X3LAT=CGMSLA 
      X3LON=CGMSLO 
      X4LAT=A(1,K,I)
      X4LON=A(2,K,I)
      GO TO 5
C***********************************************************************
C     STATEMENT 3... CHECK TO SEE IF J IS WITHIN BOUNDS.  IF OUT OF
C    BOUNDS, RESTORE TO IN BOUNDS 
C***********************************************************************
    3 IF(J.GT.36)J = J - 36
      IF(J.LT.1)J = J + 36
C***********************************************************************
C     FIND CGLAT AND CGLON OF THE FOUR CORNERS OF RECTENGLE WITHIN WHICH
C     AND GGLON FALL.  THE CORNERS OF THE RECTANGLE ARE X1, X2, X3, AND 
C     REFERS TO THE NORTHWESTERLY MOST POINT OF THE RECTANGLE.  THE LABE
C     IN A COUNTERCLOCKWISE MANNER.
C***********************************************************************
      X1LAT = A(1,J,I)
      X1LON = A(2,J,I)
      X2LAT = A(1,J,I+1)
      X2LON = A(2,J,I+1)
C***********************************************************************
C     CHECK TO SEE IF THE EASTERLY EDGE OF THE RECTANGLE IS WITHIN THE L
C     ARGUMENT BOUNDS OF ARRAY A. 
C***********************************************************************
      K = J + 1
      IF(K.GT.36)K = K - 36
      X3LAT = A(1,K,I+1)
      X3LON = A(2,K,I+1)
      X4LAT = A(1,K,I)
      X4LON = A(2,K,I)
C***********************************************************************
C     ELIMINATE THE DISCONTINUITIES IN THE X1, X2, X3, AND X4 LONGITUDES
C     WOULD OCCUR IF THE PRIME MERIDIAN OF THE CORRECTED GEOMAGNETIC COO
C     SYSTEM PASSED THROUGH RECTANGLE X1, X2, X3, X4. 
C***********************************************************************
5     Y = AMAX1(X1LON,X2LON,X3LON,X4LON)
      IF(ABS(Y-X1LON).GT.180.0)X1LON = X1LON + 360.0
      IF(ABS(Y-X2LON).GT.180.0)X2LON = X2LON + 360.0
      IF(ABS(Y-X3LON).GT.180.0)X3LON = X3LON + 360.0
      IF(ABS(Y-X4LON).GT.180.0)X4LON = X4LON + 360.0
C***********************************************************************
C     CALCULATE THE SOUTHERN AND THE WESTWARD BOUNDARIES (GEOGRAPHIC LAT
C     AND LONGITUDE) OF THE RECTANGLE. 
C***********************************************************************
      EGGLA = FLOAT(-2*I + 88)
      WGGLO = FLOAT(10*J - 10)
C***********************************************************************
C     CALCULATE THE COEFFICIENTS OF THE INTERPOLATION EQUATION.  THESE
C     COEFFICIENTS REPRESENT THE FRACTIONAL PART OF THE BOX THE POINT GG
C     GGLON IS FROM THE SOUTHERN AND THE WESTWARD BOUNDARIES OF THE RECT
C***********************************************************************
      ALPHA = (GGLAT - EGGLA)/2.0
      BETA = (GGLON - WGGLO)/10.
C***********************************************************************
C     NOW CALCULATE THE CORRECTED GEOMAGNETIC COORDINATES THAT CORRESPON
C     GEOGRAPHIC COORDINATES OF THE INPUT POINT (GGLAT,GGLON) 
C***********************************************************************
      CGLAT = X2LAT + ALPHA*(X1LAT - X2LAT) + BETA*(X3LAT - X2LAT) + 
     1(ALPHA*BETA)*(X4LAT + X2LAT - X1LAT - X3LAT)
      CGLON = X2LON + ALPHA*(X1LON - X2LON) + BETA*(X3LON - X2LON) + 
     1(ALPHA*BETA)*(X4LON + X2LON - X1LON - X3LON)
C***********************************************************************
C     CHECK TO DETERMINE IF THE CORRECTED GEOMAGNETIC LONGITUDE IS LESS 
C     DEGREES.  IF IT IS NOT REDUCE THE CALCULATED VALUE BY 360.0 DEGREE
C***********************************************************************
      IF(CGLON.GT.360.0)CGLON = CGLON - 360.0
    4 RETURN
      END
